@charset "UTF-8";
.p-tq-mv {
  background-color: #FFF;
  padding-top: 150px;
}
.p-tq-mv-wrap {
  position: relative;
}
.p-tq-mv__img {
  margin: 0 0 0 auto;
  width: 676px;
  line-height: 0;
  box-shadow: 22px 22px 0px 0px rgb(198, 198, 198);
}
.p-tq-mv__img img {
  width: 100%;
}
.p-tq-mv__ttlarea {
  position: absolute;
  bottom: 5rem;
  left: 0;
  width: 50%;
  background-color: rgba(0, 0, 0, 0.5);
  color: #FFF;
  padding: 1rem;
}
.p-tq-mv__ttl {
  font-weight: bold;
  font-size: 33px;
  padding: 2rem 2rem 2rem 2rem;
  border-bottom: 1px solid #FFF;
}
.p-tq-mv__name {
  font-weight: bold;
  padding: 1.5rem;
}
.p-tq-mv__name_01 {
  font-size: 20px;
  padding-right: 1em;
}
.p-tq-mv__name_02 {
  font-size: 32px;
}
.p-tq-mv__name_03 {
  font-size: 20px;
}
.p-tq-mv__flex {
  padding-top: 8rem;
  display: flex;
  justify-content: space-between;
}
.p-tq-mv__dates {
  font-size: 20px;
  font-weight: 500;
}
.p-tq-mv__date {
  padding-right: 1em;
}
.p-tq-mv__readtime {
  font-size: 24px;
  font-weight: 500;
}
.p-tq-main {
  background-color: #E5E5E5;
  font-feature-settings: "palt";
}
.p-tq-main-inner {
  background-color: #FFF;
  overflow: hidden;
}
.p-tq-expert {
  padding: 0;
  position: relative;
}
.p-tq-expert__img {
  width: 220px;
  line-height: 0;
  box-shadow: 18px 18px 0px 0px rgb(198, 198, 198);
  position: absolute;
  left: 3rem;
  top: 2rem;
}
.p-tq-expert__img img {
  width: 100%;
  height: auto;
}
.p-tq-expert-box {
  width: 950px;
  margin: 0 3rem auto auto;
  background-color: #E5E5E5;
  padding: 2.5rem 2rem 2.5rem 6rem;
}
.p-tq-expert__org {
  font-size: 20px;
  font-weight: bold;
  padding-left: 1rem;
}
.p-tq-expert__name {
  font-weight: 500;
  font-size: 20px;
  margin-bottom: 1rem;
  padding-left: 1rem;
}
.p-tq-expert__name span {
  font-size: 36px;
}
.p-tq-expert__profile {
  font-size: 18px;
  font-weight: 500;
  line-height: 2;
  margin-bottom: 1rem;
  padding-left: 1rem;
}
.p-tq-expert__url {
  border-top: 2px solid #707070;
  border-bottom: 2px solid #707070;
}
.p-tq-expert__url a {
  display: block;
  color: #000;
  padding: 1rem;
}
.p-tq-expert__url a:hover {
  opacity: 0.7;
}
.p-tq-summary-box {
  margin: 0 3rem;
  border: 6px solid #E5E5E5;
  border-radius: 30px;
  padding: 30px;
}
.p-tq-summary-box p {
  font-weight: 500;
  font-size: 20px;
  margin-bottom: 2em;
  line-height: 1.8;
}
.p-tq-summary-box p:last-child {
  margin-bottom: 0;
}
.p-tq-index {
  padding-top: 0;
}
.p-tq-index__h2 {
  font-size: 30px;
  font-weight: bold;
  letter-spacing: 0.1em;
  padding: 0 3rem;
  margin-bottom: 2rem;
}
.p-tq-index__h2 span {
  display: block;
  border-top: 2px solid #808080;
  font-weight: bold;
  font-size: 24px;
  color: #808080;
  padding-top: 0.5rem;
  margin-top: 0.5rem;
}
.p-tq-index__nav {
  width: 94vw;
  max-width: 1000px;
  margin: 0 auto;
}
.p-tq-index__list {
  list-style: none;
}
.p-tq-index__list li {
  margin-bottom: 4px;
}
.p-tq-index__list li a {
  display: block;
  position: relative;
}
.p-tq-index__list li a::after {
  display: block;
  width: 16px;
  height: 16px;
  content: "";
  background: url(img/ico_arrow_04.svg) no-repeat 0 0;
  background-size: contain;
  position: absolute;
  right: 1rem;
  top: calc(50% - 8px);
}
.p-tq-index__list li a:hover {
  opacity: 0.7;
}
.p-tq-index__list .p-tq-index__item--h1 a::after {
  display: none;
}
.p-tq-index__item--h1 a {
  font-weight: bold;
  font-size: 26px;
  letter-spacing: 0.1em;
  text-align: center;
  color: #FFF;
  background-color: #A4A4A4;
  padding: 0.2em 0;
}
.p-tq-index__item--h2 a {
  font-weight: 500;
  font-size: 22px;
  letter-spacing: 0.1em;
  text-align: left;
  color: #000;
  background-color: #e5e5e5;
  padding: 0.4em 3em 0.4em 3em;
}
.p-tq-recommend {
  position: relative;
  padding-top: 0;
  border-bottom: 80px solid #E5E5E5;
}
.p-tq-recommend__h2 {
  text-align: center;
  color: #FFF;
  background-color: #808080;
  font-size: 30px;
  font-weight: bold;
  letter-spacing: 0.1em;
  padding: 0.5rem 0;
}
.p-tq-recommend__ttlja {
  text-align: center;
  color: #808080;
  font-size: 24px;
  font-weight: bold;
  padding-top: 0.5rem;
  letter-spacing: 0.1em;
  margin-bottom: 1rem;
}
.p-tq-recommend-slider {
  width: 900px;
  margin: auto;
  overflow: hidden;
}
.p-tq-recommend-slider a {
  display: block;
  text-align: center;
  color: #000;
  font-weight: 500;
  font-size: 20px;
  line-height: 1.8;
  letter-spacing: 0.1em;
  opacity: 0.7;
}
.p-tq-recommend-slider img {
  width: 100%;
}
.p-tq-recommend-slider__wrap {
  padding-bottom: 40px;
  border-bottom: 10px solid #808080;
}
.p-tq-recommend-btn {
  margin-top: 1rem;
}
.p-tq-recommend-btn img {
  width: 22px;
}
.p-tq-recommend .swiper-button-prev, .p-tq-recommend .swiper-container-rtl .swiper-button-next {
  background-image: url(img/ico_arrow_01.svg);
  left: 4rem;
  right: auto;
}
.p-tq-recommend .swiper-button-next, .p-tq-recommend .swiper-container-rtl .swiper-button-prev {
  background-image: url(img/ico_arrow_02.svg);
  right: 4rem;
  left: auto;
}
.p-tq-recommend .swiper-button-next, .p-tq-recommend .swiper-button-prev {
  position: absolute;
  top: 50%;
  width: 60px;
  height: 60px;
  margin-top: -30px;
  z-index: 10;
  cursor: pointer;
  background-size: 60px 60px;
  background-position: center;
  background-repeat: no-repeat;
}
.p-tq-article {
  padding-bottom: 0;
}
.p-tq-item__h2 {
  width: 100%;
  text-align: center;
  font-weight: bold;
  font-size: 40px;
  letter-spacing: 0.1em;
  margin-bottom: 4rem;
  position: relative;
  padding: 0 14rem;
}
.p-tq-item__h2::before {
  content: "";
  width: 185px;
  height: 40px;
  background: url(img/ico_h2_02.png) no-repeat 0 0;
  background-size: contain;
  display: block;
  position: absolute;
  left: 3rem;
  top: calc(50% - 20px);
}
.p-tq-item__h2::after {
  content: "";
  width: 185px;
  height: 40px;
  background: url(img/ico_h2_01.png) no-repeat 0 0;
  background-size: contain;
  display: block;
  position: absolute;
  right: 3rem;
  top: calc(50% - 20px);
}
.p-tq-item__h3 {
  text-align: center;
  font-weight: bold;
  font-size: 32px;
  letter-spacing: 0.1em;
  margin-bottom: 4rem;
}
.p-tq-item__h3::after {
  content: "";
  width: 900px;
  height: 8px;
  background: url(img/ico_h3.svg) no-repeat 0 0;
  background-size: contain;
  display: block;
  margin: 1rem auto 0 auto;
}
.p-tq-item__h4 {
  text-align: center;
  font-weight: bold;
  font-size: 28px;
  letter-spacing: 0.1em;
  margin-bottom: 4rem;
}
.p-tq-item__textarea {
  line-height: 1.8;
  max-width: 900px;
  margin: auto auto 4rem auto;
}
.p-tq-item__textarea--left {
  text-align: left;
}
.p-tq-item__textarea--center {
  text-align: center;
}
.p-tq-item__textarea p {
  font-size: 20px;
  font-weight: 500;
  margin-bottom: 2em;
}
.p-tq-item__img--large {
  margin-bottom: 4rem;
  text-align: center;
}
.p-tq-item__img--large img {
  width: 100%;
  max-width: 750px;
}
.p-tq-item__img--small {
  margin-bottom: 4rem;
  text-align: center;
}
.p-tq-item__img--small img {
  width: 80%;
  max-width: 540px;
}
.p-tq-item__hr--divider {
  height: 2px;
  background-color: #707070;
  border: none;
  width: 94vw;
  max-width: 1000px;
  margin: auto auto 4rem auto;
}
.p-tq-item__hr--paragraph {
  height: 80px;
  background-color: #E5E5E5;
  border: none;
  width: 100%;
  margin: auto auto 6rem auto;
}
.p-tq-item__device {
  width: 900px;
  margin: auto auto 4rem auto;
  border-radius: 30px;
  border: 8px solid #E5E5E5;
  padding: 1rem 2rem;
  display: flex;
  justify-content: space-between;
}
.p-tq-item__device__image {
  width: 173px;
}
.p-tq-item__device__image img {
  width: 100%;
}
.p-tq-item__device__body {
  width: 630px;
}
.p-tq-item__device__name {
  text-align: center;
  font-weight: bold;
  font-size: 28px;
  letter-spacing: 0.1em;
  border-bottom: 4px solid #E5E5E5;
  padding-bottom: 0.5rem;
}
.p-tq-item__device__desc {
  padding: 0.5rem;
  list-style: disc;
  font-size: 22px;
  font-weight: 500;
}
.p-tq-item__device__desc li {
  width: 48%;
  float: left;
  margin-left: 2%;
  margin-top: 0.5rem;
}
.p-tq-item__point {
  width: 1000px;
  margin: 0 auto 4rem auto;
  border-radius: 30px;
  border: 8px solid #E5E5E5;
  padding: 2rem 3rem;
  display: flex;
  justify-content: space-between;
}
.p-tq-item__point__image {
  width: 120px;
}
.p-tq-item__point__body {
  width: 620px;
  margin: auto;
  text-align: center;
}
.p-tq-item__point__body p {
  font-size: 28px;
  font-weight: 500;
  line-height: 1.8;
}
.p-tq-wellgood {
  background: #ccbb9d;
  padding: 19px;
}
.p-tq-wellgood__item {
  border: 2px solid #FFF;
  padding: 19px;
  display: flex;
  justify-content: space-between;
}
.p-tq-wellgood__thumb {
  width: 400px;
  border-radius: 50px;
  overflow: hidden;
  line-height: 1;
}
.p-tq-wellgood__thumb img {
  width: 100%;
}
.p-tq-wellgood__body {
  width: 683px;
}
.p-tq-wellgood__link {
  display: block;
  color: #FFF;
}
.p-tq-wellgood__link:hover {
  opacity: 0.7;
}
.p-tq-wellgood__title {
  font-weight: 500;
  font-size: 45px;
  padding-top: 0.5rem;
}
.p-tq-wellgood__expert {
  background: url(img/bg-wellgood.svg) no-repeat 0 bottom;
  background-size: contain;
  font-weight: 100;
  font-size: 20px;
  letter-spacing: 0.15em;
  text-align: right;
  padding: 0 3.7rem 1.8rem 0;
}
.p-tq-wellgood__expert span {
  font-size: 36px;
}
.p-tq-wellgood__logo {
  font-weight: 100;
  font-size: 22px;
  letter-spacing: 0.2em;
}
.p-tq-tag-in {
  margin-bottom: 60px;
}
.p-tq-tag-in ul {
  display: flex;
  justify-content: center;
  gap: 10px;
}
.p-tq-tag-in li {
  border: 1px solid #808080;
  border-radius: 8px;
  color: #000;
  font-size: 20px;
  padding: 0.3em 1em;
  background-color: #FFF;
  font-weight: bold;
  text-align: center;
}
@media (max-width: 767px) {
  .p-tq-tag-in {
    margin-bottom: 20px;
  }
  .p-tq-tag-in ul {
    display: block;
    justify-content: inherit;
    gap: 0;
    margin: auto 1rem;
  }
  .p-tq-tag-in li {
    display: inline-block;
    border-radius: 8px;
    font-size: 14px;
    padding: 0.3em 1em;
    margin-bottom: 0.5rem;
  }
}

/* ---------- スマホ（縦積み・文字縮小） ---------- */
@media (max-width: 767px) {
  .p-tq-main {
    padding-top: 20px;
  }
  /* MV */
  .p-tq-mv {
    padding-top: 80px;
  }
  .p-tq-mv-wrap {
    padding-bottom: 36vw;
  }
  .p-tq-mv__img {
    width: 100%;
    box-shadow: 10px 10px 0 0 rgb(198, 198, 198);
    margin-right: -2vw;
  }
  .p-tq-mv__ttlarea {
    position: absolute;
    width: 90%;
    bottom: 0;
    left: -4vw;
  }
  .p-tq-mv__ttl {
    font-size: 16.5px;
    padding: 1rem;
  }
  .p-tq-mv__name {
    padding: 1rem;
  }
  .p-tq-mv__name_01,
  .p-tq-mv__name_03 {
    font-size: 12px;
  }
  .p-tq-mv__name_02 {
    font-size: 16px;
  }
  .p-tq-mv__flex {
    padding-top: 2rem;
  }
  .p-tq-mv__dates {
    font-size: 10px;
  }
  .p-tq-mv__readtime {
    font-size: 11px;
  }
  /* 有識者：画像を上に積む */
  .p-tq-expert__img {
    position: absolute;
    width: 140px;
    margin: 0 auto 1rem;
    left: 0.5rem;
    top: -0.5rem;
    box-shadow: 10px 10px 0 0 rgb(198, 198, 198);
  }
  .p-tq-expert-box {
    width: auto;
    margin: 0 1rem;
    padding: 1.5rem 1rem;
  }
  .p-tq-expert__org,
  .p-tq-expert__name {
    padding-left: 150px;
  }
  .p-tq-expert__org {
    font-size: 13px;
    margin-bottom: 0.5rem;
    margin-top: 2rem;
  }
  .p-tq-expert__name {
    font-size: 10px;
  }
  .p-tq-expert__name span {
    font-size: 18px;
  }
  .p-tq-expert__profile {
    font-size: 16px;
    padding: 2rem 0 0 0;
  }
  /* 要約 */
  .p-tq-summary-box {
    margin: 0 1rem;
    padding: 20px;
    border-radius: 16px;
  }
  .p-tq-summary-box p {
    font-size: 13px;
  }
  /* INDEX */
  .p-tq-index__h2 {
    font-size: 15px;
    padding: 0 1rem;
  }
  .p-tq-index__h2 span {
    font-size: 12px;
    padding-top: 0.2rem;
    margin-top: 0.2rem;
  }
  .p-tq-index__nav {
    margin: 0 1rem;
    max-width: 100%;
    width: auto;
  }
  .p-tq-index__item--h1 a {
    font-size: 16px;
    padding: 1.5rem 1rem 1.5rem 1rem;
  }
  .p-tq-index__item--h2 a {
    font-size: 14px;
    padding: 1rem 2.5rem 1rem 1rem;
  }
  /* RECOMMEND */
  .p-tq-recommend {
    border-bottom-width: 40px;
  }
  .p-tq-recommend__h2 {
    font-size: 22px;
  }
  .p-tq-recommend__ttlja {
    font-size: 18px;
  }
  .p-tq-recommend-slider {
    width: 84%;
  }
  .p-tq-recommend-name {
    font-size: 18px;
  }
  .p-tq-recommend-btn {
    font-size: 18px;
  }
  .p-tq-recommend .swiper-button-next,
  .p-tq-recommend .swiper-button-prev {
    width: 40px;
    height: 40px;
    margin-top: -20px;
    background-size: 40px 40px;
  }
  .p-tq-recommend .swiper-button-prev {
    left: 0.5rem;
  }
  .p-tq-recommend .swiper-button-next {
    right: 0.5rem;
  }
  /* 記事見出し（左右アイコンは非表示に） */
  .p-tq-item__h2 {
    font-size: 20px;
    padding: 0 3rem;
    margin-bottom: 2rem;
  }
  .p-tq-item__h2::before {
    content: "";
    width: 42px;
    height: 20px;
    background: url(img/ico_h2_02_sp.png) no-repeat 0 0;
    background-size: contain;
    display: block;
    position: absolute;
    left: 0;
    top: 0.5em;
  }
  .p-tq-item__h2::after {
    content: "";
    width: 42px;
    height: 20px;
    background: url(img/ico_h2_01_sp.png) no-repeat 0 0;
    background-size: contain;
    display: block;
    position: absolute;
    right: 0;
    top: 0.5em;
  }
  .p-tq-item__h3 {
    font-size: 16px;
    margin: 0 1rem 2rem 1rem;
  }
  .p-tq-item__h3::after {
    content: "";
    width: 100%;
    height: 5px;
    background: url(img/ico_h3_sp.svg) no-repeat 0 0;
    background-size: contain;
    display: block;
    margin: 0.5rem auto 0 auto;
  }
  .p-tq-item__h4 {
    font-size: 16px;
    margin: 0 1rem 2rem 1rem;
  }
  /* 本文 */
  .p-tq-item__textarea {
    max-width: 100%;
    margin-bottom: 2rem;
    padding: 0 1rem;
  }
  .p-tq-item__textarea p {
    font-size: 18px;
  }
  /* 画像 */
  .p-tq-item__img--large,
  .p-tq-item__img--small {
    margin-bottom: 2rem;
    padding: 0 1rem;
  }
  .p-tq-item__img--small img {
    width: 70%;
  }
  /* 区切り線 */
  .p-tq-item__hr--paragraph {
    height: 40px;
    margin-bottom: 3rem;
  }
  .p-tq-item__hr--divider {
    margin-left: 1rem;
    margin-right: 1rem;
  }
  /* 使用機器：縦積み */
  .p-tq-item__device {
    width: auto;
    margin: 0 1rem 2rem;
    flex-direction: column;
    padding: 1.5rem 1rem;
    border: 4px solid #E5E5E5;
    border-radius: 15px;
  }
  .p-tq-item__device__image {
    width: 40%;
    margin: 0;
    float: left;
  }
  .p-tq-item__device__body {
    width: 100%;
  }
  .p-tq-item__device__name {
    font-size: 16px;
  }
  .p-tq-item__device__desc {
    font-size: 13px;
    width: 100%;
    padding-left: 45%;
  }
  .p-tq-item__device__desc li {
    width: 100%;
    float: none;
    margin-left: 0;
  }
  /* ポイント：縦積み */
  .p-tq-item__point {
    width: auto;
    margin: 0 1rem 2rem;
    flex-direction: column;
    padding: 1.5rem 1rem;
    border: 4px solid #E5E5E5;
    border-radius: 15px;
  }
  .p-tq-item__point__image {
    width: 80px;
    margin: 0 auto 1rem;
  }
  .p-tq-item__point__image img {
    width: 100%;
  }
  .p-tq-item__point__body {
    width: 100%;
  }
  .p-tq-item__point__body p {
    font-size: 16px;
  }
  /* ウェルグッド：縦積み */
  .p-tq-wellgood__item {
    flex-direction: column;
    padding: 12px;
  }
  .p-tq-wellgood__thumb {
    width: 75%;
    margin-left: auto;
    border-radius: 24px;
    margin-bottom: 1rem;
  }
  .p-tq-wellgood__body {
    width: 100%;
  }
  .p-tq-wellgood__title {
    font-size: 22px;
    margin-top: -6rem;
    margin-bottom: 1rem;
    text-shadow: 0px 0px 7px rgb(0, 0, 0);
  }
  .p-tq-wellgood__expert {
    font-size: 16px;
    text-align: center;
    padding: 0 0 1rem;
    padding-right: 2rem;
    font-weight: 400;
  }
  .p-tq-wellgood__expert {
    text-align: right;
    font-size: 13px;
  }
  .p-tq-wellgood__expert span {
    font-size: 20px;
  }
  .p-tq-wellgood__logo {
    font-size: 15px;
    font-weight: 400;
  }
  .p-tq-wellgood__logo img {
    width: 145px;
  }
  .p-tq-wellgood__logo span {
    font-size: 11px;
    letter-spacing: 0;
  }
}
.p-tq-top {
  padding-top: 100px;
}

@media (max-width: 767px) {
  .p-tq-top {
    padding-top: 0;
  }
}
.home main section .inner {
  width: 1200px;
}

@media (max-width: 767px) {
  .home main section .inner {
    width: 92vw;
  }
}
.p-tq-top {
  font-feature-settings: "palt";
}

/* ===== MVヒーロー：最新記事のFV画像を3枚横並び ===== */
.p-tq-hero {
  padding: 40px 0 60px 0;
  background-color: #FFF;
  overflow: hidden;
  letter-spacing: 0.15em;
  position: relative;
}
.p-tq-hero h2 {
  text-align: center;
  width: 100%;
  font-weight: bold;
  font-size: 60px;
  padding-bottom: 1rem;
}
.p-tq-hero h3 {
  text-align: center;
  width: 100%;
  font-weight: bold;
  font-size: 35px;
}

.p-tq-hero__wrap {
  position: absolute;
  top: 34%;
  width: 100%;
  z-index: 10;
}

.p-tq-hero__list {
  opacity: 0.3;
  list-style: none;
  margin: 0;
  padding: 0;
  width: 100%;
  display: flex;
  flex-wrap: nowrap;
  /* justify-content/gap はSwiperのspaceBetweenに任せる（競合回避） */
}

.p-tq-hero__item {
  line-height: 0;
}

.p-tq-hero__item img {
  width: 100%;
  height: auto;
  display: block;
  box-shadow: 15px 15px 0 0 rgb(198, 198, 198);
}

.p-tq-hero__lead {
  text-align: center;
  font-weight: bold;
  font-size: 20px;
  line-height: 1.8;
  padding-top: 2rem;
}

.p-tq-hero .swiper-slide {
  flex-shrink: 0;
  /* 固定幅を付けない（Swiperに任せる） */
}

/* PCのみ：スライド1枚の幅（中央1枚＋左右見切れの約2.6枚表示） */
@media (min-width: 768px) {
  .p-tq-hero .swiper-slide {
    width: 38vw;
  }
}
@media (max-width: 767px) {
  .p-tq-hero {
    padding: 30px 0;
    height: auto;
  }
  .p-tq-hero__wrap {
    top: 34%;
  }
  .p-tq-hero h2 {
    font-size: 28px;
  }
  .p-tq-hero h3 {
    font-size: 17px;
  }
  .p-tq-hero__lead {
    font-size: 12px;
  }
  /* Swiperのflexラッパーをグリッドで上書き（詳細度を上げる） */
  .p-tq-hero .p-tq-hero__list {
    display: grid;
    grid-template-columns: repeat(2, minmax(0, 1fr)); /* 0起点。左右均等に配置 */
    width: calc(100% + 20vw); /* 画面より広げて…             */
    margin-left: -10vw; /* …左右の端に均等にはみ出す（ブリード） */
    -moz-column-gap: 13.5vw;
         column-gap: 13.5vw; /* 中央の隙間（重なり防止）      */
    row-gap: 16px; /* 上下段の隙間                 */
    opacity: 0.3;
  }
  .p-tq-hero__item {
    margin: 0;
    width: auto;
    min-width: 0; /* グリッドセルが画像実寸で膨らむのを防ぐ */
    aspect-ratio: var(--ar, 4/5); /* 各画像の実寸比率(PHPから)で高さを最初から確定 */
  }
  .p-tq-hero__item img {
    width: 100%;
    height: 100%;
    -o-object-fit: cover;
       object-fit: cover; /* 枠にフィット（差し替え時も縦ブレなし） */
    box-shadow: 8px 8px 0 0 rgb(198, 198, 198);
  }
  .p-tq-hero__item:nth-child(even) {
    margin-top: 20px;
  }
  /* 2行目（3・4枚目）だけ左へずらす。数値を大きくするほど左へ */
  .p-tq-hero__item:nth-child(3),
  .p-tq-hero__item:nth-child(4) {
    transform: translateX(-15vw);
  }
  .p-tq-hero__item:nth-child(n+5) {
    display: none;
  } /* スマホは4枚（2行）まで */
}
/* ===== カテゴリータブ ===== */
.p-tq-top-tabs__list {
  display: flex;
  flex-wrap: nowrap;
  justify-content: center;
  gap: 10px;
  list-style: none;
  width: -moz-fit-content;
  width: fit-content;
  max-width: 96vw;
  margin: 0 auto;
  padding: 20px 0;
}
.p-tq-top-tabs__btn {
  display: block;
  width: 100%;
  border: none;
  cursor: pointer;
  font-family: inherit;
  background: #808080;
  color: #FFF;
  font-weight: bold;
  font-size: 21px;
  letter-spacing: 0.03em;
  white-space: nowrap;
  padding: 0.7em 1.4em;
  border-radius: 10px;
}
.p-tq-top-tabs__btn:hover {
  opacity: 0.8;
}
.p-tq-top-tabs__btn.is-current {
  background: #FFF;
  color: #000;
}

/* ===== NEW 見出し ===== */
.p-tq-new {
  background: #e5e5e5;
  padding: 40px 0 80px;
}
.p-tq-new__h2 {
  text-align: center;
  margin-bottom: 3rem;
}
.p-tq-new__desc {
  display: block;
  font-size: 40px;
  font-weight: bold;
  letter-spacing: 0.1em;
}
.p-tq-new__name {
  display: block;
  width: 86vw;
  max-width: 1100px;
  margin: 0.5rem auto 0;
  padding-top: 0.5rem;
  border-top: 2px solid #808080;
  font-size: 22px;
  font-weight: bold;
  color: #808080;
}
.p-tq-new__list {
  list-style: none;
  margin: 0 auto;
  padding: 0;
  width: 94vw;
  max-width: 1050px;
  display: grid;
  grid-template-columns: repeat(3, 1fr);
  gap: 48px 30px;
}
.p-tq-new__empty {
  text-align: center;
  padding: 4rem 0;
}
.p-tq-new-box {
  background-color: #FFF;
  padding: 60px 0;
}

/* ===== カード ===== */
.p-tq-newcard {
  display: block;
  text-decoration: none;
  color: #000;
}
.p-tq-newcard:hover {
  opacity: 0.85;
}
.p-tq-newcard__thumb {
  line-height: 0;
  margin-bottom: 1.5rem;
  box-shadow: 12px 12px 0 0 rgb(198, 198, 198);
}
.p-tq-newcard__thumb img {
  width: 100%;
}
.p-tq-newcard__ttlarea {
  background: #808080;
  color: #FFF;
  padding: 1rem;
}
.p-tq-newcard__ttl {
  font-weight: bold;
  font-size: 20px;
  line-height: 1.4;
  padding-bottom: 0.8rem;
  border-bottom: 1px solid #FFF;
}
.p-tq-newcard__name {
  font-weight: bold;
  padding-top: 0.8rem;
}
.p-tq-newcard__name_01 {
  font-size: 14px;
  padding-right: 0.8em;
}
.p-tq-newcard__name_02 {
  font-size: 20px;
}
.p-tq-newcard__name_03 {
  font-size: 14px;
}
.p-tq-newcard__excerpt {
  font-size: 15px;
  line-height: 1.7;
  margin-top: 1rem;
}
.p-tq-newcard__tags {
  display: flex;
  flex-wrap: wrap;
  gap: 8px;
  margin-top: 0.8rem;
}

/* ===== カテゴリタグ ===== */
.p-tq-tag {
  display: inline-block;
  border: 1px solid #808080;
  border-radius: 8px;
  color: #000;
  font-size: 14px;
  padding: 0.3em 1em;
}

/* ===== ページ送り ===== */
.p-tq-pager {
  display: flex;
  justify-content: center;
  flex-wrap: wrap;
  gap: 8px;
  margin-top: 3rem;
}
.p-tq-pager .page-numbers {
  display: inline-block;
  padding: 0.4em 0.8em;
  border: 1px solid #808080;
  border-radius: 6px;
  text-decoration: none;
  color: #000;
}
.p-tq-pager .page-numbers.current {
  background: #808080;
  color: #FFF;
}
.p-tq-pager .page-numbers:hover {
  opacity: 0.8;
}

/* ===== レスポンシブ ===== */
@media (max-width: 1040px) {
  .p-tq-new__list {
    grid-template-columns: repeat(2, 1fr);
  }
}
@media (max-width: 767px) {
  .p-tq-top-tabs__list {
    flex-wrap: wrap;
    max-width: 100%;
    gap: 1%;
  }
  .p-tq-top-tabs__btn {
    font-size: 10px;
    padding: 0.6em 1em;
    border-radius: 8px;
  }
  .p-tq-top-tabs__item {
    width: 32%;
    margin-bottom: 1%;
  }
  .p-tq-new__desc {
    font-size: 28px;
  }
  .p-tq-new__name {
    font-size: 18px;
  }
  .p-tq-new__list {
    grid-template-columns: 1fr;
    gap: 32px;
  }
  .p-tq-newcard__ttl {
    font-size: 18px;
  }
  .p-tq-newcard__name_02 {
    font-size: 18px;
  }
  .p-tq-new-box {
    padding: 20px 0;
  }
}/*# sourceMappingURL=technique.css.map */